@@ -37,7 +37,8 @@ class Variogram(object):
                  use_nugget=False,
                  maxlag=None,
                  n_lags=10,
-                 verbose=False
+                 verbose=False,
+                 **kwargs,
                  ):
         r"""Variogram Class
 
@@ -151,7 +152,22 @@ class Variogram(object):
         verbose : bool
             Set the Verbosity of the class. Not Implemented yet.
 
+        Keyword Arguments
+        -----------------
+        entropy_bins : int, str
+            .. versionadded:: 0.3.7
+            If the `estimator <skgstat.Variogram.estimator>` is set to
+            `'entropy'` this argument sets the number of bins, that should be
+            used for histogram calculation.
+        percentile : int
+            .. versionadded:: 0.3.7
+            If the `estimator <skgstat.Variogram.estimator>` is set to 
+            `'entropy'` this argument sets the percentile to be used.
+
         """
+        # Before we do anything else, make kwargs available
+        self._kwargs = self._validate_kwargs(**kwargs)
+
         # Set coordinates
         self._X = np.asarray(coordinates)
 
@@ -174,6 +190,7 @@ class Variogram(object):
         self.set_dist_function(func=dist_func)
 
         # lags and max lag
+        self._n_lags_passed_value = n_lags
         self._n_lags = None
         self.n_lags = n_lags
         self._maxlag = None
@@ -191,6 +208,7 @@ class Variogram(object):
         self.set_model(model_name=model)
 
         # the binning settings
+        self._bin_func_name = None
         self._bin_func = None
         self._groups = None
         self._bins = None
@@ -359,7 +377,7 @@ class Variogram(object):
     def bin_func(self, bin_func):
         self.set_bin_func(bin_func=bin_func)
 
-    def set_bin_func(self, bin_func):
+    def set_bin_func(self, bin_func: str):
         """Set binning function
 
         Sets a new binning function to be used. The new binning method is set
@@ -395,6 +413,9 @@ class Variogram(object):
             self._bin_func = binning.uniform_count_lags
         else:
             raise ValueError('%s binning method is not known' % bin_func)
+        
+        # store the name
+        self._bin_func_name = bin_func
 
         # reset groups and bins
         self._groups = None
@@ -459,6 +480,9 @@ class Variogram(object):
         # else
         else:
             raise ValueError('n_lags has to be a positive integer')
+        
+        # if there are no errors, store the passed value
+        self._n_lags_passed_value = n
 
         # reset the groups
         self._groups = None
@@ -777,6 +801,42 @@ class Variogram(object):
         self.cof = None
         self.cov = None
 
+    def update_kwargs(self, **kwargs):
+        """
+        .. versionadded:: 0.3.7
+
+        Update the keyword arguments of this Variogram instance.
+        The keyword arguments will be validated first and the update the
+        existing kwargs. That means, you can pass only the kwargs, which
+        need to be updated.
+
+        .. note::
+            Updating the kwargs does not force a preprocessing circle. 
+            Any affected intermediate result, that might be cached internally, 
+            will not make use of updated kwargs. Make a call to 
+            :func:`preprocessing(force=True) <skgstat.Variogram.preprocessing>`
+            to force a clean re-calculation of the Variogram instance.
+
+        """
+        old = self._kwargs
+
+        # update the keyword-arguments
+        updated = self._validate_kwargs(**kwargs)
+        old.update(updated)
+
+        self._kwargs = old
+
+    def _validate_kwargs(self, **kwargs):
+        """
+        .. versionadded:: 0.3.7
+
+        This functions actually does nothing right now.
+        It will be used in the future, as soon as the Variogram takes
+        more kwargs. Then, these can be checked here.
+
+        """
+        return kwargs
+
     def lag_groups(self):
         """Lag class groups
 
@@ -1112,6 +1172,10 @@ class Variogram(object):
 
         .. versionchanged:: 0.3.6
             replaced the for-loops with :func:`fromiter <numpy.fromiter>`
+        
+        .. versionchanged:: 0.3.7
+            makes use of `kwargs <skgstat.Variogram._kwargs>` for 
+            specific estimators now 
 
         Returns
         -------
@@ -1121,17 +1185,28 @@ class Variogram(object):
 
         """
         if self._estimator.__name__ == 'entropy':
-            bins = np.linspace(
-                np.min(self.distance),
-                np.max(self.distance),
-                50      # TODO: this should be set by kwargs
-            )
+            # get the parameter from kwargs, if not set use 50
+            N = self._kwargs.get('entropy_bins', 50)
 
+            # we need to use N -1 as we use the last inclusive
+            if isinstance(N, int):
+                N -= 1
+            
+            bins = np.histogram_bin_edges(self.distance, bins=N)
+
+            # define the mapper to the estimator function
             def mapper(lag_values):
                 return self._estimator(lag_values, bins=bins)
+
         elif self._estimator.__name__ == 'percentile':
-            # TODO after the kwargs are accepted, the p value can be set here
-            mapper = self._estimator
+            if self._kwargs.get('percentile', False):
+                p = self._kwargs.get('percentile')
+
+                def mapper(lag_values):
+                    return self._estimator(lag_values, p=p)
+            else:
+                mapper = self._estimator
+
         else:
             mapper = self._estimator
 
@@ -1414,14 +1489,33 @@ class Variogram(object):
 
         return _exp, _model
 
-    def describe(self):
+    def describe(self, short=False, flat=False):
         """Variogram parameters
 
         Return a dictionary of the variogram parameters.
 
+        .. versionchanged:: 0.3.7
+            The describe now returns all init parameters in as the 
+            `describe()['params']` key and all keyword arguments as
+            `describe()['kwargs']`. This output can be suppressed 
+            by setting `short=True`.
+        
+        Parameters
+        ----------
+        short : bool
+            If `True`, the `'params'` and `'kwargs'` keys will be 
+            omitted. Defaults to `False`.
+        flat : bool
+            If `True`, the `'params'` and `'kwargs'` nested `dict`s
+            will be distributed to the main `dict` to return a 
+            flat `dict`. Defaults to `False`
+
         Returns
         -------
-        dict
+        parameters : dict
+            Returns fitting parameters of the theoretical variogram
+            model along with the init parameters of the 
+            `Variogram <skgstat.Variogram>` instance.
 
         """
         # fit, if not already done
@@ -1454,6 +1548,31 @@ class Variogram(object):
         elif self._model.__name__ == 'stable':
             rdict['shape'] = cof[2]
 
+        # add other stuff if not short version requested
+        if not short:
+            kwargs = self._kwargs
+            params = dict(
+                estimator=self._estimator.__name__,
+                model=self._model.__name__,
+                dist_func=str(self._dist_func_name),
+                bin_func=self._bin_func_name,
+                normalize=self.normalized,
+                fit_method=self.fit_method,
+                fit_sigma=self.fit_sigma,
+                use_nugget=self.use_nugget,
+                maxlag=self.maxlag,
+                n_lags=self._n_lags_passed_value,
+                verbose=self.verbose
+            )
+
+            # update or append the params
+            if flat:
+                rdict.update(params)
+                rdict.update(kwargs)
+            else:
+                rdict['params'] = params
+                rdict['kwargs'] = kwargs
+
         # return
         return rdict
 
